==> rendition-9.4.0.tgz: package/dist_esm5/components/Table/TableRow.js <==
import * as tslib_1 from "tslib";
import get from 'lodash/get';
import isFunction from 'lodash/isFunction';
import map from 'lodash/map';
import * as React from 'react';
var renderField = function (row, column) {
    var value = get(row, column.field);
    if (column.render) {
        return column.render(value, row);
    }
    return value == null ? '' : value;
};
var TableRow = (function (_super) {
    tslib_1.__extends(TableRow, _super);
    function TableRow() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TableRow.prototype.render = function () {
        var _this = this;
        var _a = this.props, attributes = _a.attributes, checkboxAttributes = _a.checkboxAttributes, columns = _a.columns, className = _a.className, data = _a.data, href = _a.href, keyAttribute = _a.keyAttribute, isChecked = _a.isChecked, isHighlighted = _a.isHighlighted, showCheck = _a.showCheck;
        return (React.createElement("div", { "data-display": "table-row", "data-highlight": isChecked || isHighlighted, className: className },
            showCheck && (React.createElement("span", { "data-display": "table-cell" },
                React.createElement("input", tslib_1.__assign({ checked: isChecked, "data-key": keyAttribute, onChange: this.props.toggleChecked }, checkboxAttributes, { type: "checkbox" })))),
            map(columns, function (column) {
                var cellAttributes = isFunction(column.cellAttributes)
                    ? column.cellAttributes(data, get(data, column.field))
                    : column.cellAttributes || {};
                return (React.createElement("a", tslib_1.__assign({}, attributes, { href: href, "data-display": "table-cell", "data-key": keyAttribute, onClick: _this.props.onRowClick }, cellAttributes, { key: column.field }), renderField(data, column)));
            })));
    };
    return TableRow;
}(React.PureComponent));
export { TableRow };

==> rendition-11.10.0.tgz: package/dist_esm5/components/Table/TableRow.js <==
import * as tslib_1 from "tslib";
import get from 'lodash/get';
import isFunction from 'lodash/isFunction';
import map from 'lodash/map';
import * as React from 'react';
var renderField = function (row, column) {
    var value = get(row, column.field);
    if (column.render) {
        return column.render(value, row);
    }
    return value == null ? '' : value;
};
var TableRow = (function (_super) {
    tslib_1.__extends(TableRow, _super);
    function TableRow() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TableRow.prototype.render = function () {
        var _this = this;
        var _a = this.props, attributes = _a.attributes, checkboxAttributes = _a.checkboxAttributes, columns = _a.columns, className = _a.className, data = _a.data, href = _a.href, keyAttribute = _a.keyAttribute, isChecked = _a.isChecked, isHighlighted = _a.isHighlighted, isDisabled = _a.isDisabled, showCheck = _a.showCheck;
        return (React.createElement("div", { "data-display": "table-row", "data-highlight": isChecked || isHighlighted, className: className },
            showCheck && (React.createElement("span", { "data-display": "table-cell" },
                React.createElement("input", tslib_1.__assign({ checked: isChecked, disabled: isDisabled, "data-key": keyAttribute, onChange: this.props.toggleChecked }, checkboxAttributes, { type: "checkbox" })))),
            map(columns, function (column) {
                var cellAttributes = isFunction(column.cellAttributes)
                    ? column.cellAttributes(data, get(data, column.field))
                    : column.cellAttributes || {};
                return (React.createElement("a", tslib_1.__assign({}, attributes, { href: href, "data-display": "table-cell", "data-key": keyAttribute, onClick: _this.props.onRowClick }, cellAttributes, { key: column.field }), renderField(data, column)));
            })));
    };
    return TableRow;
}(React.PureComponent));
export { TableRow };
